@@ -9,27 +9,28 @@ global platform_
 platform_ = platform
 
 
-def main(chdir='.'):
+def main(chdir="."):
     os.chdir(chdir)
 
-    target_fpath = 'chromedriver.exe' if platform == 'win32' else 'chromedriver'
+    target_fpath = "chromedriver.exe" if platform == "win32" else "chromedriver"
     target_fpath = str((Path(chdir) / target_fpath).resolve())
     if os.path.isfile(target_fpath):
         return target_fpath
 
     # get the latest chrome driver version number
-    url = 'https://chromedriver.storage.googleapis.com/LATEST_RELEASE'
+    url = "https://chromedriver.storage.googleapis.com/LATEST_RELEASE"
     response = requests.get(url)
     version_number = response.text
 
     global platform_
-    if platform_ == 'darwin':
+    if platform_ == "darwin":
         import cpuinfo
+
         # Just get the manufacturer of the processors
-        manufacturer = cpuinfo.get_cpu_info().get('brand_raw')
+        manufacturer = cpuinfo.get_cpu_info().get("brand_raw")
         # 'Apple M1 Pro'
-        if 'm1' in manufacturer.lower():
-            platform_ += 'm1'
+        if "m1" in manufacturer.lower():
+            platform_ += "m1"
 
     os_specific = {
         "linux": "chromedriver_linux64.zip",
@@ -39,26 +40,25 @@ def main(chdir='.'):
         "win32": "chromedriver_win32.zip",
     }
 
-
-
     # build the donwload url
-    download_url = "https://chromedriver.storage.googleapis.com/" + version_number + '/' + os_specific[platform_]
+    download_url = "https://chromedriver.storage.googleapis.com/" + version_number + "/" + os_specific[platform_]
 
     # download the zip file using the url built above
-    latest_driver_zip = wget.download(download_url, 'chromedriver.zip')
+    latest_driver_zip = wget.download(download_url, "chromedriver.zip")
 
     # extract the zip file
-    with zipfile.ZipFile(latest_driver_zip, 'r') as zip_ref:
-        zip_ref.extractall() # you can specify the destination folder path here
+    with zipfile.ZipFile(latest_driver_zip, "r") as zip_ref:
+        zip_ref.extractall()  # you can specify the destination folder path here
     # delete the zip file downloaded above
     os.remove(latest_driver_zip)
     return target_fpath
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # argparser to take in the directory to extract the driver to
     import argparse
-    parser = argparse.ArgumentParser(description='Download the latest chrome driver')
-    parser.add_argument('--chdir', default='.', help='directory to extract the driver to')
+
+    parser = argparse.ArgumentParser(description="Download the latest chrome driver")
+    parser.add_argument("--chdir", default=".", help="directory to extract the driver to")
     args = parser.parse_args()
     main(args.chdir)
